#!/usr/bin/env python
"""
Input files must be supplied from command line as:

            python mediaeval_f1.py <input-dir> <input-ground-truth> <output-csv>

<input-dir> : path to directory containing all the runs
<input-ground-truth> : path to ground truth file
<output-csv> : path to output file

Input files should be formatted in such a way that
column-1 : track-ids
column-2 : start_time_stamp
column-3 : end_time_stamp
column-4 : labels
column-5 : unique_row_ids
"""
import csv
import os
import sys
from simple_f import f_weighted

if len(sys.argv) == 4:
    y_true = {}
    inputdir = str(sys.argv[1])
    with open(str(sys.argv[2]), 'r') as truth_file: #replace with directory containing ground truth
        truth_reader = csv.reader(truth_file)
        for row in truth_reader:
            if int(row[3]) != 4: #replace with column number of predicted label
                y_true[row[4]]=row[3] #dictionary to keep track of which rows to take into account
        print len(y_true)
    for root, dirs, files in os.walk(inputdir):
        rel_path = os.path.relpath(root, inputdir)
        with open(str(sys.argv[3]),'w') as csvfile: #output file handle
            csv_writer = csv.writer(csvfile)
            csv_writer.writerow(["Filename", "#Ground Labels", "#Predicted Labels", "weighted-mean", "label-score", "true-label-count", "pred-label-count"])
            for filename in files:
                y_pred = {}
                file_dir = os.path.join(root, filename)
                with open(file_dir, 'r') as pred_file:
                    pred_reader = csv.reader(pred_file)
                    for row in pred_reader:
                        if row[4] in y_true:
                            y_pred[row[4]] = row[3] #replace with column number of predicted label
                print filename, len(y_pred)
                print "unweighted"
                print "weighted"
                f_score, f_label, true_label_count, pred_label_count = f_weighted(y_true.values(), y_pred.values(), labels={1,2,3})
                new_row = [filename, len(y_true), len(y_pred), f_score, f_label, true_label_count, pred_label_count]
                csv_writer.writerow(new_row)
else:
    print("Error - input must be: python mediaeval_f1.py <input-dir> <input-ground-truth> <output-csv>")
    sys.exit(0)