"""
The algorithm emulates a confusion matrix without building one to maintain simplicity, not recommended for very large lists.

The function must be supplied with two lists and the list of labels
y_true : ground truth labels
y_pred : predicted labels
labels : labels found in y_true and y_pred

It must be ensured that both lists are of similar size and have similar labels.
"""
def f_weighted(y_true, y_pred, labels):
    sets = zip(y_true, y_pred)
    true_count_list = [] #list containing the number of elements in each label of ground truth
    pred_count_list = [] #list containing the number of elements in each label of pred labels
    f_label = [] #list containing the f score for each label
    for label in labels:
        true_count = 0 #temporary variable to track number of elements in each label of ground truth
        pred_count = 0 #temporary variable to track number of elements in each label of predicted
        recall_hit = 0
        recall_miss = 0
        precision_hit = 0
        precision_miss = 0
        for s1, s2 in sets:
            if int(s1) == label: #check if set of similar true labels are equal to predicted labels
                true_count += 1
                if s1 == s2:
                    recall_hit += 1
                else:
                    recall_miss += 1
            if int(s2) == label: #check if set of similar predicted labels are equal to true labels
                pred_count +=1
                if s2 ==s1:
                    precision_hit += 1
                else:
                    precision_miss += 1
        try:
            recall = 1.0 * recall_hit/(recall_hit + recall_miss)
            precision = 1.0 * precision_hit/(precision_hit + precision_miss)
            f_score = 2.0 * precision * recall/(precision + recall)
            f_label.append(f_score)
        except:
            f_label.append(0)
        true_count_list.append(true_count)
        pred_count_list.append(pred_count)
    return sum(f_score*count for f_score,count in zip(f_label,true_count_list)) / sum(true_count_list), f_label, true_count_list, pred_count_list